@@ -73,7 +73,7 @@ def checks_header_fields(*fields):
     header_fields_with_dedicated_checks.update(fields)
     return identity
 
-class Checker(object, metaclass=abc.ABCMeta):
+class Checker(metaclass=abc.ABCMeta):
 
     _patched_environment = None
 
@@ -107,7 +107,7 @@ class Checker(object, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def tag(self, tagname, *extra):
-        return
+        pass
 
     def check(self):
         # If a file passed to polib doesn't exist, it will “helpfully” treat it
@@ -145,7 +145,7 @@ class Checker(object, metaclass=abc.ABCMeta):
         except polib4us.moparser.SyntaxError as exc:
             self.tag('invalid-mo-file', tags.safestr(exc))
             return
-        except IOError as exc:
+        except OSError as exc:
             message = str(exc)
             if exc.errno is not None:
                 self.tag('os-error', tags.safestr(exc.strerror))
